@@ -1705,15 +1705,15 @@ initD3D11(HWND hWnd) {
             float specular[4];
         } lightSource[2];
     } lightingData = {
-        0.5, 0.2f, 1.0f, 0.0f,
-        0.1f, 0.1f, 0.1f, 1.0f,
-        0.7f, 0.7f, 0.7f, 1.0f,
-        0.8f, 0.8f, 0.8f, 1.0f,
+        {{ { 0.5, 0.2f, 1.0f, 0.0f },
+           { 0.1f, 0.1f, 0.1f, 1.0f },
+           { 0.7f, 0.7f, 0.7f, 1.0f },
+           { 0.8f, 0.8f, 0.8f, 1.0f } },
 
-        -0.8f, 0.4f, -1.0f, 0.0f,
-        0.0f, 0.0f, 0.0f, 1.0f,
-        0.5f, 0.5f, 0.5f, 1.0f,
-        0.8f, 0.8f, 0.8f, 1.0f,
+         { { -0.8f, 0.4f, -1.0f, 0.0f },
+           { 0.0f, 0.0f, 0.0f, 1.0f },
+           { 0.5f, 0.5f, 0.5f, 1.0f },
+           { 0.8f, 0.8f, 0.8f, 1.0f } }},
     };
 
     D3D11_BUFFER_DESC cbDesc;
